menufw/menufwui/mmwidgets/inc/mmgrid.h
branchRCL_3
changeset 9 f966699dea19
parent 4 4d54b72983ae
child 16 9674c1a575e9
--- a/menufw/menufwui/mmwidgets/inc/mmgrid.h	Tue Feb 02 00:04:13 2010 +0200
+++ b/menufw/menufwui/mmwidgets/inc/mmgrid.h	Fri Feb 19 22:42:37 2010 +0200
@@ -12,7 +12,7 @@
 * Contributors:
 *
 * Description:  CMmGrid declaration
-*  Version     : %version: MM_32.1.22 % << Don't touch! Updated by Synergy at check-out.
+*  Version     : %version: MM_32.1.23 % << Don't touch! Updated by Synergy at check-out.
 *
 */
 
@@ -415,12 +415,12 @@
      * This function typically calls @c ProcessScrollEventL,
      * which actually scrolls the view and causes a redraw. 
      */
-    void HandleRedrawTimerEvent();
+    void HandleRedrawTimerEventL();
     
 private:
     /**
      * Callback function for @c iRedrawTimer.
      * It simply calls @c HandleRedrawTimerEvent and returns 0.
      * 
      * @param aPtr A pointer to CMmGrid object.
      * @return 0 (always).
@@ -415,12 +415,12 @@
     /**
      * Callback function for @c iRedrawTimer.
-     * It simply calls @c HandleRedrawTimerEvent and returns 0.
+     * It simply calls @c HandleRedrawTimerEventL and returns 0.
      * 
      * @param aPtr A pointer to CMmGrid object.